Référence API
=============


.. module:: flask_jeroboam.view_arguments.functions
   :noindex:


.. autofunction:: Path
   :noindex:


.. autofunction:: Query
   :noindex:


.. autofunction:: Header
   :noindex:


.. autofunction:: Cookie
   :noindex:


.. autofunction:: Body
   :noindex:

.. autofunction:: Form
   :noindex:


.. autofunction:: File
   :noindex:
